==> owncloud-4.0.4.tgz: owncloud/core/l10n/tr.php <==
<?php $TRANSLATIONS = array(
"Application name not provided." => "Uygulama adı verilmedi.",
"No category to add?" => "Eklenecek kategori yok?",
"This category already exists: " => "Bu kategori zaten mevcut: ",
"Owncloud password reset" => "Owncloud parola sıfırlama",
"ownCloud password reset" => "ownCloud parola sıfırlama",
"Use the following link to reset your password: {link}" => "Bu bağlantıyı kullanarak parolanızı sıfırlayın: {link}",
"You will receive a link to reset your password via Email." => "Parolanızı sıfırlamak için bir bağlantı Eposta olarak gönderilecek.",
"Requested" => "İstendi",
"Login failed!" => "Giriş başarısız!",
"Username" => "Kullanıcı adı",
"Request reset" => "Sıfırlama iste",
"Your password was reset" => "Parolanız sıfırlandı",
"To login page" => "Giriş sayfasına git",
"New password" => "Yeni parola",
"Reset password" => "Parolayı sıfırla",
"Personal" => "Kişisel",
"Users" => "Kullanıcılar",
"Apps" => "Uygulamalar",
"Admin" => "Yönetici",
"Help" => "Yardı",
"Access forbidden" => "Erişim yasaklı",
"Cloud not found" => "Bulut bulunamadı",
"Edit categories" => "Kategorileri düzenle",
"Add" => "Ekle",
"Create an <strong>admin account</strong>" => "Bir <strong>yönetici hesabı</strong> oluşturun",
"Password" => "Parola",
"Advanced" => "Gelişmiş",
"Data folder" => "Veri klasörü",
"Configure the database" => "Veritabanını ayarla",
"will be used" => "kullanılacak",
"Database user" => "Veritabanı kullanıcı adı",
"Database password" => "Veritabanı parolası",
"Database name" => "Veritabanı adı",
"Database host" => "Veritabanı sunucusu",
"Finish setup" => "Kurulumu tamamla",
"web services under your control" => "kontrolünüzdeki web servisleri",
"Log out" => "Çıkış yap",
"Settings" => "Ayarlar",
"Lost your password?" => "Parolanızı mı unuttunuz?",
"remember" => "hatırla",
"Log in" => "Giriş yap",
"You are logged out." => "Çıkış yaptınız.",
"prev" => "önceki",
"next" => "sonraki"
);

==> owncloud-4.5.7.tgz: owncloud/core/l10n/tr.php <==
<?php $TRANSLATIONS = array(
"Application name not provided." => "Uygulama adı verilmedi.",
"No category to add?" => "Eklenecek kategori yok?",
"This category already exists: " => "Bu kategori zaten mevcut: ",
"Settings" => "Ayarlar",
"January" => "Ocak",
"February" => "Şubat",
"March" => "Mart",
"April" => "Nisan",
"May" => "Mayıs",
"June" => "Haziran",
"July" => "Temmuz",
"August" => "Ağustos",
"September" => "Eylül",
"October" => "Ekim",
"November" => "Kasım",
"December" => "Aralık",
"Cancel" => "İptal",
"No" => "Hayır",
"Yes" => "Evet",
"Ok" => "Tamam",
"No categories selected for deletion." => "Silmek için bir kategori seçilmedi",
"Error" => "Hata",
"Password" => "Parola",
"ownCloud password reset" => "ownCloud parola sıfırlama",
"Use the following link to reset your password: {link}" => "Bu bağlantıyı kullanarak parolanızı sıfırlayın: {link}",
"You will receive a link to reset your password via Email." => "Parolanızı sıfırlamak için bir bağlantı Eposta olarak gönderilecek.",
"Requested" => "İstendi",
"Login failed!" => "Giriş başarısız!",
"Username" => "Kullanıcı adı",
"Request reset" => "Sıfırlama iste",
"Your password was reset" => "Parolanız sıfırlandı",
"To login page" => "Giriş sayfasına git",
"New password" => "Yeni parola",
"Reset password" => "Parolayı sıfırla",
"Personal" => "Kişisel",
"Users" => "Kullanıcılar",
"Apps" => "Uygulamalar",
"Admin" => "Yönetici",
"Help" => "Yardı",
"Access forbidden" => "Erişim yasaklı",
"Cloud not found" => "Bulut bulunamadı",
"Edit categories" => "Kategorileri düzenle",
"Add" => "Ekle",
"Create an <strong>admin account</strong>" => "Bir <strong>yönetici hesabı</strong> oluşturun",
"Advanced" => "Gelişmiş",
"Data folder" => "Veri klasörü",
"Configure the database" => "Veritabanını ayarla",
"will be used" => "kullanılacak",
"Database user" => "Veritabanı kullanıcı adı",
"Database password" => "Veritabanı parolası",
"Database name" => "Veritabanı adı",
"Database tablespace" => "Veritabanı tablo alanı",
"Database host" => "Veritabanı sunucusu",
"Finish setup" => "Kurulumu tamamla",
"web services under your control" => "kontrolünüzdeki web servisleri",
"Log out" => "Çıkış yap",
"Lost your password?" => "Parolanızı mı unuttunuz?",
"remember" => "hatırla",
"Log in" => "Giriş yap",
"You are logged out." => "Çıkış yaptınız.",
"prev" => "önceki",
"next" => "sonraki"
);
